# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetSsoProviderResult',
    'AwaitableGetSsoProviderResult',
    'get_sso_provider',
    'get_sso_provider_output',
]

@pulumi.output_type
class GetSsoProviderResult:
    """
    A collection of values returned by getSsoProvider.
    """
    def __init__(__self__, id=None, name=None, type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the SSO provider.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the SSO provider.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The type of SSO provider.
        """
        return pulumi.get(self, "type")


class AwaitableGetSsoProviderResult(GetSsoProviderResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSsoProviderResult(
            id=self.id,
            name=self.name,
            type=self.type)


def get_sso_provider(id: Optional[_builtins.str] = None,
                     name: Optional[_builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSsoProviderResult:
    """
    Data source for retrieving an SSO providers


    :param _builtins.str id: Unique identifier of the SSO provider.
    :param _builtins.str name: The name of the SSO provider.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:index/getSsoProvider:getSsoProvider', __args__, opts=opts, typ=GetSsoProviderResult).value

    return AwaitableGetSsoProviderResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        type=pulumi.get(__ret__, 'type'))
def get_sso_provider_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSsoProviderResult]:
    """
    Data source for retrieving an SSO providers


    :param _builtins.str id: Unique identifier of the SSO provider.
    :param _builtins.str name: The name of the SSO provider.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:index/getSsoProvider:getSsoProvider', __args__, opts=opts, typ=GetSsoProviderResult)
    return __ret__.apply(lambda __response__: GetSsoProviderResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['OverridesArgs', 'Overrides']

@pulumi.input_type
class OverridesArgs:
    def __init__(__self__, *,
                 env_id: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 git_details: Optional[pulumi.Input['OverridesGitDetailsArgs']] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 infra_id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_force_import: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_id: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Overrides resource.
        :param pulumi.Input[_builtins.str] env_id: The environment ID to which the overrides are associated.
        :param pulumi.Input[_builtins.str] type: The type of the overrides.
        :param pulumi.Input[_builtins.str] cluster_id: The cluster ID to which the overrides are associated.
        :param pulumi.Input['OverridesGitDetailsArgs'] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input[_builtins.str] identifier: The identifier of the override entity.
        :param pulumi.Input[_builtins.bool] import_from_git: import override from git
        :param pulumi.Input[_builtins.str] infra_id: The infrastructure ID to which the overrides are associated.
        :param pulumi.Input[_builtins.bool] is_force_import: force import override from remote even if same file path already exist
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] service_id: The service ID to which the overrides applies.
        :param pulumi.Input[_builtins.str] yaml: The yaml of the override entity
        """
        pulumi.set(__self__, "env_id", env_id)
        pulumi.set(__self__, "type", type)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if git_details is not None:
            pulumi.set(__self__, "git_details", git_details)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if import_from_git is not None:
            pulumi.set(__self__, "import_from_git", import_from_git)
        if infra_id is not None:
            pulumi.set(__self__, "infra_id", infra_id)
        if is_force_import is not None:
            pulumi.set(__self__, "is_force_import", is_force_import)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if yaml is not None:
            pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter(name="envId")
    def env_id(self) -> pulumi.Input[_builtins.str]:
        """
        The environment ID to which the overrides are associated.
        """
        return pulumi.get(self, "env_id")

    @env_id.setter
    def env_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "env_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the overrides.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The cluster ID to which the overrides are associated.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> Optional[pulumi.Input['OverridesGitDetailsArgs']]:
        """
        Contains parameters related to creating an Entity for Git Experience.
        """
        return pulumi.get(self, "git_details")

    @git_details.setter
    def git_details(self, value: Optional[pulumi.Input['OverridesGitDetailsArgs']]):
        pulumi.set(self, "git_details", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier of the override entity.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        import override from git
        """
        return pulumi.get(self, "import_from_git")

    @import_from_git.setter
    def import_from_git(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "import_from_git", value)

    @_builtins.property
    @pulumi.getter(name="infraId")
    def infra_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The infrastructure ID to which the overrides are associated.
        """
        return pulumi.get(self, "infra_id")

    @infra_id.setter
    def infra_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "infra_id", value)

    @_builtins.property
    @pulumi.getter(name="isForceImport")
    def is_force_import(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        force import override from remote even if same file path already exist
        """
        return pulumi.get(self, "is_force_import")

    @is_force_import.setter
    def is_force_import(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_force_import", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The service ID to which the overrides applies.
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_id", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The yaml of the override entity
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "yaml", value)


@pulumi.input_type
class _OverridesState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 env_id: Optional[pulumi.Input[_builtins.str]] = None,
                 git_details: Optional[pulumi.Input['OverridesGitDetailsArgs']] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 infra_id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_force_import: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Overrides resources.
        :param pulumi.Input[_builtins.str] cluster_id: The cluster ID to which the overrides are associated.
        :param pulumi.Input[_builtins.str] env_id: The environment ID to which the overrides are associated.
        :param pulumi.Input['OverridesGitDetailsArgs'] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input[_builtins.str] identifier: The identifier of the override entity.
        :param pulumi.Input[_builtins.bool] import_from_git: import override from git
        :param pulumi.Input[_builtins.str] infra_id: The infrastructure ID to which the overrides are associated.
        :param pulumi.Input[_builtins.bool] is_force_import: force import override from remote even if same file path already exist
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] service_id: The service ID to which the overrides applies.
        :param pulumi.Input[_builtins.str] type: The type of the overrides.
        :param pulumi.Input[_builtins.str] yaml: The yaml of the override entity
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if env_id is not None:
            pulumi.set(__self__, "env_id", env_id)
        if git_details is not None:
            pulumi.set(__self__, "git_details", git_details)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if import_from_git is not None:
            pulumi.set(__self__, "import_from_git", import_from_git)
        if infra_id is not None:
            pulumi.set(__self__, "infra_id", infra_id)
        if is_force_import is not None:
            pulumi.set(__self__, "is_force_import", is_force_import)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if yaml is not None:
            pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The cluster ID to which the overrides are associated.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="envId")
    def env_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The environment ID to which the overrides are associated.
        """
        return pulumi.get(self, "env_id")

    @env_id.setter
    def env_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "env_id", value)

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> Optional[pulumi.Input['OverridesGitDetailsArgs']]:
        """
        Contains parameters related to creating an Entity for Git Experience.
        """
        return pulumi.get(self, "git_details")

    @git_details.setter
    def git_details(self, value: Optional[pulumi.Input['OverridesGitDetailsArgs']]):
        pulumi.set(self, "git_details", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier of the override entity.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        import override from git
        """
        return pulumi.get(self, "import_from_git")

    @import_from_git.setter
    def import_from_git(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "import_from_git", value)

    @_builtins.property
    @pulumi.getter(name="infraId")
    def infra_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The infrastructure ID to which the overrides are associated.
        """
        return pulumi.get(self, "infra_id")

    @infra_id.setter
    def infra_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "infra_id", value)

    @_builtins.property
    @pulumi.getter(name="isForceImport")
    def is_force_import(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        force import override from remote even if same file path already exist
        """
        return pulumi.get(self, "is_force_import")

    @is_force_import.setter
    def is_force_import(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_force_import", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The service ID to which the overrides applies.
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the overrides.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The yaml of the override entity
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "yaml", value)


@pulumi.type_token("harness:platform/overrides:Overrides")
class Overrides(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 env_id: Optional[pulumi.Input[_builtins.str]] = None,
                 git_details: Optional[pulumi.Input[Union['OverridesGitDetailsArgs', 'OverridesGitDetailsArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 infra_id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_force_import: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Harness Override V2.

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level override

        ```sh
        $ pulumi import harness:platform/overrides:Overrides example <override_id>
        ```

        Import org level override

        ```sh
        $ pulumi import harness:platform/overrides:Overrides example <org_id>/<override_id>
        ```

        Import project level override

        ```sh
        $ pulumi import harness:platform/overrides:Overrides example <org_id>/<project_id>/<override_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_id: The cluster ID to which the overrides are associated.
        :param pulumi.Input[_builtins.str] env_id: The environment ID to which the overrides are associated.
        :param pulumi.Input[Union['OverridesGitDetailsArgs', 'OverridesGitDetailsArgsDict']] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input[_builtins.str] identifier: The identifier of the override entity.
        :param pulumi.Input[_builtins.bool] import_from_git: import override from git
        :param pulumi.Input[_builtins.str] infra_id: The infrastructure ID to which the overrides are associated.
        :param pulumi.Input[_builtins.bool] is_force_import: force import override from remote even if same file path already exist
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] service_id: The service ID to which the overrides applies.
        :param pulumi.Input[_builtins.str] type: The type of the overrides.
        :param pulumi.Input[_builtins.str] yaml: The yaml of the override entity
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OverridesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness Override V2.

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level override

        ```sh
        $ pulumi import harness:platform/overrides:Overrides example <override_id>
        ```

        Import org level override

        ```sh
        $ pulumi import harness:platform/overrides:Overrides example <org_id>/<override_id>
        ```

        Import project level override

        ```sh
        $ pulumi import harness:platform/overrides:Overrides example <org_id>/<project_id>/<override_id>
        ```

        :param str resource_name: The name of the resource.
        :param OverridesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OverridesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 env_id: Optional[pulumi.Input[_builtins.str]] = None,
                 git_details: Optional[pulumi.Input[Union['OverridesGitDetailsArgs', 'OverridesGitDetailsArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
                 infra_id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_force_import: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OverridesArgs.__new__(OverridesArgs)

            __props__.__dict__["cluster_id"] = cluster_id
            if env_id is None and not opts.urn:
                raise TypeError("Missing required property 'env_id'")
            __props__.__dict__["env_id"] = env_id
            __props__.__dict__["git_details"] = git_details
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["import_from_git"] = import_from_git
            __props__.__dict__["infra_id"] = infra_id
            __props__.__dict__["is_force_import"] = is_force_import
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["service_id"] = service_id
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["yaml"] = yaml
        super(Overrides, __self__).__init__(
            'harness:platform/overrides:Overrides',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
            env_id: Optional[pulumi.Input[_builtins.str]] = None,
            git_details: Optional[pulumi.Input[Union['OverridesGitDetailsArgs', 'OverridesGitDetailsArgsDict']]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            import_from_git: Optional[pulumi.Input[_builtins.bool]] = None,
            infra_id: Optional[pulumi.Input[_builtins.str]] = None,
            is_force_import: Optional[pulumi.Input[_builtins.bool]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            service_id: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            yaml: Optional[pulumi.Input[_builtins.str]] = None) -> 'Overrides':
        """
        Get an existing Overrides resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_id: The cluster ID to which the overrides are associated.
        :param pulumi.Input[_builtins.str] env_id: The environment ID to which the overrides are associated.
        :param pulumi.Input[Union['OverridesGitDetailsArgs', 'OverridesGitDetailsArgsDict']] git_details: Contains parameters related to creating an Entity for Git Experience.
        :param pulumi.Input[_builtins.str] identifier: The identifier of the override entity.
        :param pulumi.Input[_builtins.bool] import_from_git: import override from git
        :param pulumi.Input[_builtins.str] infra_id: The infrastructure ID to which the overrides are associated.
        :param pulumi.Input[_builtins.bool] is_force_import: force import override from remote even if same file path already exist
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] service_id: The service ID to which the overrides applies.
        :param pulumi.Input[_builtins.str] type: The type of the overrides.
        :param pulumi.Input[_builtins.str] yaml: The yaml of the override entity
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OverridesState.__new__(_OverridesState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["env_id"] = env_id
        __props__.__dict__["git_details"] = git_details
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["import_from_git"] = import_from_git
        __props__.__dict__["infra_id"] = infra_id
        __props__.__dict__["is_force_import"] = is_force_import
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["service_id"] = service_id
        __props__.__dict__["type"] = type
        __props__.__dict__["yaml"] = yaml
        return Overrides(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[_builtins.str]:
        """
        The cluster ID to which the overrides are associated.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter(name="envId")
    def env_id(self) -> pulumi.Output[_builtins.str]:
        """
        The environment ID to which the overrides are associated.
        """
        return pulumi.get(self, "env_id")

    @_builtins.property
    @pulumi.getter(name="gitDetails")
    def git_details(self) -> pulumi.Output['outputs.OverridesGitDetails']:
        """
        Contains parameters related to creating an Entity for Git Experience.
        """
        return pulumi.get(self, "git_details")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        The identifier of the override entity.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="importFromGit")
    def import_from_git(self) -> pulumi.Output[_builtins.bool]:
        """
        import override from git
        """
        return pulumi.get(self, "import_from_git")

    @_builtins.property
    @pulumi.getter(name="infraId")
    def infra_id(self) -> pulumi.Output[_builtins.str]:
        """
        The infrastructure ID to which the overrides are associated.
        """
        return pulumi.get(self, "infra_id")

    @_builtins.property
    @pulumi.getter(name="isForceImport")
    def is_force_import(self) -> pulumi.Output[_builtins.bool]:
        """
        force import override from remote even if same file path already exist
        """
        return pulumi.get(self, "is_force_import")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Output[_builtins.str]:
        """
        The service ID to which the overrides applies.
        """
        return pulumi.get(self, "service_id")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the overrides.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> pulumi.Output[_builtins.str]:
        """
        The yaml of the override entity
        """
        return pulumi.get(self, "yaml")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetTokenResult',
    'AwaitableGetTokenResult',
    'get_token',
    'get_token_output',
]

@pulumi.output_type
class GetTokenResult:
    """
    A collection of values returned by getToken.
    """
    def __init__(__self__, account_id=None, apikey_id=None, apikey_type=None, description=None, email=None, encoded_password=None, id=None, identifier=None, name=None, org_id=None, parent_id=None, project_id=None, scheduled_expire_time=None, tags=None, username=None, valid=None, valid_from=None, valid_to=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if apikey_id and not isinstance(apikey_id, str):
            raise TypeError("Expected argument 'apikey_id' to be a str")
        pulumi.set(__self__, "apikey_id", apikey_id)
        if apikey_type and not isinstance(apikey_type, str):
            raise TypeError("Expected argument 'apikey_type' to be a str")
        pulumi.set(__self__, "apikey_type", apikey_type)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if encoded_password and not isinstance(encoded_password, str):
            raise TypeError("Expected argument 'encoded_password' to be a str")
        pulumi.set(__self__, "encoded_password", encoded_password)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if parent_id and not isinstance(parent_id, str):
            raise TypeError("Expected argument 'parent_id' to be a str")
        pulumi.set(__self__, "parent_id", parent_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if scheduled_expire_time and not isinstance(scheduled_expire_time, int):
            raise TypeError("Expected argument 'scheduled_expire_time' to be a int")
        pulumi.set(__self__, "scheduled_expire_time", scheduled_expire_time)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)
        if valid and not isinstance(valid, bool):
            raise TypeError("Expected argument 'valid' to be a bool")
        pulumi.set(__self__, "valid", valid)
        if valid_from and not isinstance(valid_from, int):
            raise TypeError("Expected argument 'valid_from' to be a int")
        pulumi.set(__self__, "valid_from", valid_from)
        if valid_to and not isinstance(valid_to, int):
            raise TypeError("Expected argument 'valid_to' to be a int")
        pulumi.set(__self__, "valid_to", valid_to)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> _builtins.str:
        """
        Account Identifier for the Entity
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="apikeyId")
    def apikey_id(self) -> _builtins.str:
        """
        Identifier of the API Key
        """
        return pulumi.get(self, "apikey_id")

    @_builtins.property
    @pulumi.getter(name="apikeyType")
    def apikey_type(self) -> _builtins.str:
        """
        Type of the API Key
        """
        return pulumi.get(self, "apikey_type")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[_builtins.str]:
        """
        Email Id of the user who created the Token
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter(name="encodedPassword")
    def encoded_password(self) -> Optional[_builtins.str]:
        """
        Encoded password of the Token
        """
        return pulumi.get(self, "encoded_password")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> _builtins.str:
        """
        Parent Entity Identifier of the API Key
        """
        return pulumi.get(self, "parent_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="scheduledExpireTime")
    def scheduled_expire_time(self) -> Optional[_builtins.int]:
        """
        Scheduled expiry time in milliseconds
        """
        return pulumi.get(self, "scheduled_expire_time")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[_builtins.str]:
        """
        Name of the user who created the Token
        """
        return pulumi.get(self, "username")

    @_builtins.property
    @pulumi.getter
    def valid(self) -> Optional[_builtins.bool]:
        """
        Boolean value to indicate if Token is valid or not.
        """
        return pulumi.get(self, "valid")

    @_builtins.property
    @pulumi.getter(name="validFrom")
    def valid_from(self) -> Optional[_builtins.int]:
        """
        This is the time from which the Token is valid. The time is in milliseconds
        """
        return pulumi.get(self, "valid_from")

    @_builtins.property
    @pulumi.getter(name="validTo")
    def valid_to(self) -> Optional[_builtins.int]:
        """
        This is the time till which the Token is valid. The time is in milliseconds
        """
        return pulumi.get(self, "valid_to")


class AwaitableGetTokenResult(GetTokenResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTokenResult(
            account_id=self.account_id,
            apikey_id=self.apikey_id,
            apikey_type=self.apikey_type,
            description=self.description,
            email=self.email,
            encoded_password=self.encoded_password,
            id=self.id,
            identifier=self.identifier,
            name=self.name,
            org_id=self.org_id,
            parent_id=self.parent_id,
            project_id=self.project_id,
            scheduled_expire_time=self.scheduled_expire_time,
            tags=self.tags,
            username=self.username,
            valid=self.valid,
            valid_from=self.valid_from,
            valid_to=self.valid_to)


def get_token(account_id: Optional[_builtins.str] = None,
              apikey_id: Optional[_builtins.str] = None,
              apikey_type: Optional[_builtins.str] = None,
              email: Optional[_builtins.str] = None,
              encoded_password: Optional[_builtins.str] = None,
              identifier: Optional[_builtins.str] = None,
              name: Optional[_builtins.str] = None,
              org_id: Optional[_builtins.str] = None,
              parent_id: Optional[_builtins.str] = None,
              project_id: Optional[_builtins.str] = None,
              scheduled_expire_time: Optional[_builtins.int] = None,
              username: Optional[_builtins.str] = None,
              valid: Optional[_builtins.bool] = None,
              valid_from: Optional[_builtins.int] = None,
              valid_to: Optional[_builtins.int] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTokenResult:
    """
    Data source for retrieving a Harness ApiKey Token.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_token(identifier="test_token",
        parent_id="apikey_parent_id",
        account_id="account_id",
        org_id="org_id",
        project_id="project_id",
        apikey_id="apikey_id",
        apikey_type="USER")
    ```


    :param _builtins.str account_id: Account Identifier for the Entity
    :param _builtins.str apikey_id: Identifier of the API Key
    :param _builtins.str apikey_type: Type of the API Key
    :param _builtins.str email: Email Id of the user who created the Token
    :param _builtins.str encoded_password: Encoded password of the Token
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str parent_id: Parent Entity Identifier of the API Key
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.int scheduled_expire_time: Scheduled expiry time in milliseconds
    :param _builtins.str username: Name of the user who created the Token
    :param _builtins.bool valid: Boolean value to indicate if Token is valid or not.
    :param _builtins.int valid_from: This is the time from which the Token is valid. The time is in milliseconds
    :param _builtins.int valid_to: This is the time till which the Token is valid. The time is in milliseconds
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['apikeyId'] = apikey_id
    __args__['apikeyType'] = apikey_type
    __args__['email'] = email
    __args__['encodedPassword'] = encoded_password
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['parentId'] = parent_id
    __args__['projectId'] = project_id
    __args__['scheduledExpireTime'] = scheduled_expire_time
    __args__['username'] = username
    __args__['valid'] = valid
    __args__['validFrom'] = valid_from
    __args__['validTo'] = valid_to
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getToken:getToken', __args__, opts=opts, typ=GetTokenResult).value

    return AwaitableGetTokenResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        apikey_id=pulumi.get(__ret__, 'apikey_id'),
        apikey_type=pulumi.get(__ret__, 'apikey_type'),
        description=pulumi.get(__ret__, 'description'),
        email=pulumi.get(__ret__, 'email'),
        encoded_password=pulumi.get(__ret__, 'encoded_password'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        parent_id=pulumi.get(__ret__, 'parent_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        scheduled_expire_time=pulumi.get(__ret__, 'scheduled_expire_time'),
        tags=pulumi.get(__ret__, 'tags'),
        username=pulumi.get(__ret__, 'username'),
        valid=pulumi.get(__ret__, 'valid'),
        valid_from=pulumi.get(__ret__, 'valid_from'),
        valid_to=pulumi.get(__ret__, 'valid_to'))
def get_token_output(account_id: Optional[pulumi.Input[_builtins.str]] = None,
                     apikey_id: Optional[pulumi.Input[_builtins.str]] = None,
                     apikey_type: Optional[pulumi.Input[_builtins.str]] = None,
                     email: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     encoded_password: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     identifier: Optional[pulumi.Input[_builtins.str]] = None,
                     name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     parent_id: Optional[pulumi.Input[_builtins.str]] = None,
                     project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     scheduled_expire_time: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                     username: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     valid: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                     valid_from: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                     valid_to: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTokenResult]:
    """
    Data source for retrieving a Harness ApiKey Token.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_token(identifier="test_token",
        parent_id="apikey_parent_id",
        account_id="account_id",
        org_id="org_id",
        project_id="project_id",
        apikey_id="apikey_id",
        apikey_type="USER")
    ```


    :param _builtins.str account_id: Account Identifier for the Entity
    :param _builtins.str apikey_id: Identifier of the API Key
    :param _builtins.str apikey_type: Type of the API Key
    :param _builtins.str email: Email Id of the user who created the Token
    :param _builtins.str encoded_password: Encoded password of the Token
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str parent_id: Parent Entity Identifier of the API Key
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.int scheduled_expire_time: Scheduled expiry time in milliseconds
    :param _builtins.str username: Name of the user who created the Token
    :param _builtins.bool valid: Boolean value to indicate if Token is valid or not.
    :param _builtins.int valid_from: This is the time from which the Token is valid. The time is in milliseconds
    :param _builtins.int valid_to: This is the time till which the Token is valid. The time is in milliseconds
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['apikeyId'] = apikey_id
    __args__['apikeyType'] = apikey_type
    __args__['email'] = email
    __args__['encodedPassword'] = encoded_password
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['parentId'] = parent_id
    __args__['projectId'] = project_id
    __args__['scheduledExpireTime'] = scheduled_expire_time
    __args__['username'] = username
    __args__['valid'] = valid
    __args__['validFrom'] = valid_from
    __args__['validTo'] = valid_to
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getToken:getToken', __args__, opts=opts, typ=GetTokenResult)
    return __ret__.apply(lambda __response__: GetTokenResult(
        account_id=pulumi.get(__response__, 'account_id'),
        apikey_id=pulumi.get(__response__, 'apikey_id'),
        apikey_type=pulumi.get(__response__, 'apikey_type'),
        description=pulumi.get(__response__, 'description'),
        email=pulumi.get(__response__, 'email'),
        encoded_password=pulumi.get(__response__, 'encoded_password'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        parent_id=pulumi.get(__response__, 'parent_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        scheduled_expire_time=pulumi.get(__response__, 'scheduled_expire_time'),
        tags=pulumi.get(__response__, 'tags'),
        username=pulumi.get(__response__, 'username'),
        valid=pulumi.get(__response__, 'valid'),
        valid_from=pulumi.get(__response__, 'valid_from'),
        valid_to=pulumi.get(__response__, 'valid_to')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetGitopsRepositoryResult',
    'AwaitableGetGitopsRepositoryResult',
    'get_gitops_repository',
    'get_gitops_repository_output',
]

@pulumi.output_type
class GetGitopsRepositoryResult:
    """
    A collection of values returned by getGitopsRepository.
    """
    def __init__(__self__, account_id=None, agent_id=None, enable_oci=None, id=None, identifier=None, org_id=None, project_id=None, repos=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if agent_id and not isinstance(agent_id, str):
            raise TypeError("Expected argument 'agent_id' to be a str")
        pulumi.set(__self__, "agent_id", agent_id)
        if enable_oci and not isinstance(enable_oci, bool):
            raise TypeError("Expected argument 'enable_oci' to be a bool")
        pulumi.set(__self__, "enable_oci", enable_oci)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if repos and not isinstance(repos, list):
            raise TypeError("Expected argument 'repos' to be a list")
        pulumi.set(__self__, "repos", repos)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> _builtins.str:
        """
        Account identifier of the GitOps repository.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> _builtins.str:
        """
        Agent identifier of the GitOps repository.
        """
        return pulumi.get(self, "agent_id")

    @_builtins.property
    @pulumi.getter(name="enableOci")
    def enable_oci(self) -> _builtins.bool:
        """
        Indicates if helm-oci support must be enabled for this repo.
        """
        return pulumi.get(self, "enable_oci")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the GitOps repository.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Organization identifier of the GitOps repository.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Project identifier of the GitOps repository.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def repos(self) -> Sequence['outputs.GetGitopsRepositoryRepoResult']:
        """
        Repo details holding application configurations.
        """
        return pulumi.get(self, "repos")


class AwaitableGetGitopsRepositoryResult(GetGitopsRepositoryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGitopsRepositoryResult(
            account_id=self.account_id,
            agent_id=self.agent_id,
            enable_oci=self.enable_oci,
            id=self.id,
            identifier=self.identifier,
            org_id=self.org_id,
            project_id=self.project_id,
            repos=self.repos)


def get_gitops_repository(account_id: Optional[_builtins.str] = None,
                          agent_id: Optional[_builtins.str] = None,
                          identifier: Optional[_builtins.str] = None,
                          org_id: Optional[_builtins.str] = None,
                          project_id: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGitopsRepositoryResult:
    """
    Data source for fetching a Harness GitOps Repository.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_gitops_repository(identifier="identifier",
        account_id="account_id",
        project_id="project_id",
        org_id="org_id",
        agent_id="agent_id")
    ```


    :param _builtins.str account_id: Account identifier of the GitOps repository.
    :param _builtins.str agent_id: Agent identifier of the GitOps repository.
    :param _builtins.str identifier: Identifier of the GitOps repository.
    :param _builtins.str org_id: Organization identifier of the GitOps repository.
    :param _builtins.str project_id: Project identifier of the GitOps repository.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['agentId'] = agent_id
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getGitopsRepository:getGitopsRepository', __args__, opts=opts, typ=GetGitopsRepositoryResult).value

    return AwaitableGetGitopsRepositoryResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        agent_id=pulumi.get(__ret__, 'agent_id'),
        enable_oci=pulumi.get(__ret__, 'enable_oci'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        repos=pulumi.get(__ret__, 'repos'))
def get_gitops_repository_output(account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                 org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGitopsRepositoryResult]:
    """
    Data source for fetching a Harness GitOps Repository.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_gitops_repository(identifier="identifier",
        account_id="account_id",
        project_id="project_id",
        org_id="org_id",
        agent_id="agent_id")
    ```


    :param _builtins.str account_id: Account identifier of the GitOps repository.
    :param _builtins.str agent_id: Agent identifier of the GitOps repository.
    :param _builtins.str identifier: Identifier of the GitOps repository.
    :param _builtins.str org_id: Organization identifier of the GitOps repository.
    :param _builtins.str project_id: Project identifier of the GitOps repository.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['agentId'] = agent_id
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getGitopsRepository:getGitopsRepository', __args__, opts=opts, typ=GetGitopsRepositoryResult)
    return __ret__.apply(lambda __response__: GetGitopsRepositoryResult(
        account_id=pulumi.get(__response__, 'account_id'),
        agent_id=pulumi.get(__response__, 'agent_id'),
        enable_oci=pulumi.get(__response__, 'enable_oci'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        repos=pulumi.get(__response__, 'repos')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetConnectorCustomSecretManagerResult',
    'AwaitableGetConnectorCustomSecretManagerResult',
    'get_connector_custom_secret_manager',
    'get_connector_custom_secret_manager_output',
]

@pulumi.output_type
class GetConnectorCustomSecretManagerResult:
    """
    A collection of values returned by getConnectorCustomSecretManager.
    """
    def __init__(__self__, delegate_selectors=None, description=None, id=None, identifier=None, name=None, on_delegate=None, org_id=None, project_id=None, ssh_secret_ref=None, tags=None, target_host=None, template_inputs=None, template_ref=None, timeout=None, type=None, version_label=None, working_directory=None):
        if delegate_selectors and not isinstance(delegate_selectors, list):
            raise TypeError("Expected argument 'delegate_selectors' to be a list")
        pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if on_delegate and not isinstance(on_delegate, bool):
            raise TypeError("Expected argument 'on_delegate' to be a bool")
        pulumi.set(__self__, "on_delegate", on_delegate)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if ssh_secret_ref and not isinstance(ssh_secret_ref, str):
            raise TypeError("Expected argument 'ssh_secret_ref' to be a str")
        pulumi.set(__self__, "ssh_secret_ref", ssh_secret_ref)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if target_host and not isinstance(target_host, str):
            raise TypeError("Expected argument 'target_host' to be a str")
        pulumi.set(__self__, "target_host", target_host)
        if template_inputs and not isinstance(template_inputs, list):
            raise TypeError("Expected argument 'template_inputs' to be a list")
        pulumi.set(__self__, "template_inputs", template_inputs)
        if template_ref and not isinstance(template_ref, str):
            raise TypeError("Expected argument 'template_ref' to be a str")
        pulumi.set(__self__, "template_ref", template_ref)
        if timeout and not isinstance(timeout, int):
            raise TypeError("Expected argument 'timeout' to be a int")
        pulumi.set(__self__, "timeout", timeout)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if version_label and not isinstance(version_label, str):
            raise TypeError("Expected argument 'version_label' to be a str")
        pulumi.set(__self__, "version_label", version_label)
        if working_directory and not isinstance(working_directory, str):
            raise TypeError("Expected argument 'working_directory' to be a str")
        pulumi.set(__self__, "working_directory", working_directory)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Optional[Sequence[_builtins.str]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="onDelegate")
    def on_delegate(self) -> _builtins.bool:
        """
        Specifies whether the secrets manager runs on a Harness delegate.
        """
        return pulumi.get(self, "on_delegate")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="sshSecretRef")
    def ssh_secret_ref(self) -> _builtins.str:
        """
        SSH secret reference for the custom secrets manager, Computed if 'on_delegate' is false.
        """
        return pulumi.get(self, "ssh_secret_ref")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="targetHost")
    def target_host(self) -> _builtins.str:
        """
        Host where the custom secrets manager is located, Computed if 'on_delegate' is false.
        """
        return pulumi.get(self, "target_host")

    @_builtins.property
    @pulumi.getter(name="templateInputs")
    def template_inputs(self) -> Sequence['outputs.GetConnectorCustomSecretManagerTemplateInputResult']:
        return pulumi.get(self, "template_inputs")

    @_builtins.property
    @pulumi.getter(name="templateRef")
    def template_ref(self) -> _builtins.str:
        """
        Reference to the template used for managing secrets.
        """
        return pulumi.get(self, "template_ref")

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> _builtins.int:
        """
        Timeout in seconds for secrets management operations.
        """
        return pulumi.get(self, "timeout")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Type of the custom secrets manager, typically set to 'CustomSecretManager'.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="versionLabel")
    def version_label(self) -> _builtins.str:
        """
        Version identifier of the secrets management template.
        """
        return pulumi.get(self, "version_label")

    @_builtins.property
    @pulumi.getter(name="workingDirectory")
    def working_directory(self) -> _builtins.str:
        """
        The working directory for operations, Computed if 'on_delegate' is false.
        """
        return pulumi.get(self, "working_directory")


class AwaitableGetConnectorCustomSecretManagerResult(GetConnectorCustomSecretManagerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConnectorCustomSecretManagerResult(
            delegate_selectors=self.delegate_selectors,
            description=self.description,
            id=self.id,
            identifier=self.identifier,
            name=self.name,
            on_delegate=self.on_delegate,
            org_id=self.org_id,
            project_id=self.project_id,
            ssh_secret_ref=self.ssh_secret_ref,
            tags=self.tags,
            target_host=self.target_host,
            template_inputs=self.template_inputs,
            template_ref=self.template_ref,
            timeout=self.timeout,
            type=self.type,
            version_label=self.version_label,
            working_directory=self.working_directory)


def get_connector_custom_secret_manager(delegate_selectors: Optional[Sequence[_builtins.str]] = None,
                                        identifier: Optional[_builtins.str] = None,
                                        name: Optional[_builtins.str] = None,
                                        org_id: Optional[_builtins.str] = None,
                                        project_id: Optional[_builtins.str] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConnectorCustomSecretManagerResult:
    """
    Datasource for looking up a Custom Secret Manager connector.


    :param Sequence[_builtins.str] delegate_selectors: Tags to filter delegates for connection.
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['delegateSelectors'] = delegate_selectors
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getConnectorCustomSecretManager:getConnectorCustomSecretManager', __args__, opts=opts, typ=GetConnectorCustomSecretManagerResult).value

    return AwaitableGetConnectorCustomSecretManagerResult(
        delegate_selectors=pulumi.get(__ret__, 'delegate_selectors'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        name=pulumi.get(__ret__, 'name'),
        on_delegate=pulumi.get(__ret__, 'on_delegate'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        ssh_secret_ref=pulumi.get(__ret__, 'ssh_secret_ref'),
        tags=pulumi.get(__ret__, 'tags'),
        target_host=pulumi.get(__ret__, 'target_host'),
        template_inputs=pulumi.get(__ret__, 'template_inputs'),
        template_ref=pulumi.get(__ret__, 'template_ref'),
        timeout=pulumi.get(__ret__, 'timeout'),
        type=pulumi.get(__ret__, 'type'),
        version_label=pulumi.get(__ret__, 'version_label'),
        working_directory=pulumi.get(__ret__, 'working_directory'))
def get_connector_custom_secret_manager_output(delegate_selectors: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                                               identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                               name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                               org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                               project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetConnectorCustomSecretManagerResult]:
    """
    Datasource for looking up a Custom Secret Manager connector.


    :param Sequence[_builtins.str] delegate_selectors: Tags to filter delegates for connection.
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['delegateSelectors'] = delegate_selectors
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getConnectorCustomSecretManager:getConnectorCustomSecretManager', __args__, opts=opts, typ=GetConnectorCustomSecretManagerResult)
    return __ret__.apply(lambda __response__: GetConnectorCustomSecretManagerResult(
        delegate_selectors=pulumi.get(__response__, 'delegate_selectors'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        name=pulumi.get(__response__, 'name'),
        on_delegate=pulumi.get(__response__, 'on_delegate'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        ssh_secret_ref=pulumi.get(__response__, 'ssh_secret_ref'),
        tags=pulumi.get(__response__, 'tags'),
        target_host=pulumi.get(__response__, 'target_host'),
        template_inputs=pulumi.get(__response__, 'template_inputs'),
        template_ref=pulumi.get(__response__, 'template_ref'),
        timeout=pulumi.get(__response__, 'timeout'),
        type=pulumi.get(__response__, 'type'),
        version_label=pulumi.get(__response__, 'version_label'),
        working_directory=pulumi.get(__response__, 'working_directory')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ApplicationArgs', 'Application']

@pulumi.input_type
class ApplicationArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_manual_trigger_authorized: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a Application resource.
        :param pulumi.Input[_builtins.str] description: The application description
        :param pulumi.Input[_builtins.bool] is_manual_trigger_authorized: When this is set to true, all manual triggers will require API Key authorization
        :param pulumi.Input[_builtins.str] name: The name of the application
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if is_manual_trigger_authorized is not None:
            pulumi.set(__self__, "is_manual_trigger_authorized", is_manual_trigger_authorized)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The application description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="isManualTriggerAuthorized")
    def is_manual_trigger_authorized(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When this is set to true, all manual triggers will require API Key authorization
        """
        return pulumi.get(self, "is_manual_trigger_authorized")

    @is_manual_trigger_authorized.setter
    def is_manual_trigger_authorized(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_manual_trigger_authorized", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the application
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ApplicationState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_sync_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 git_sync_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_manual_trigger_authorized: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Application resources.
        :param pulumi.Input[_builtins.str] description: The application description
        :param pulumi.Input[_builtins.str] git_sync_connector_id: The id of the git sync connector
        :param pulumi.Input[_builtins.bool] git_sync_enabled: True if git sync is enabled on this application
        :param pulumi.Input[_builtins.bool] is_manual_trigger_authorized: When this is set to true, all manual triggers will require API Key authorization
        :param pulumi.Input[_builtins.str] name: The name of the application
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if git_sync_connector_id is not None:
            pulumi.set(__self__, "git_sync_connector_id", git_sync_connector_id)
        if git_sync_enabled is not None:
            pulumi.set(__self__, "git_sync_enabled", git_sync_enabled)
        if is_manual_trigger_authorized is not None:
            pulumi.set(__self__, "is_manual_trigger_authorized", is_manual_trigger_authorized)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The application description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="gitSyncConnectorId")
    def git_sync_connector_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the git sync connector
        """
        return pulumi.get(self, "git_sync_connector_id")

    @git_sync_connector_id.setter
    def git_sync_connector_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_sync_connector_id", value)

    @_builtins.property
    @pulumi.getter(name="gitSyncEnabled")
    def git_sync_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        True if git sync is enabled on this application
        """
        return pulumi.get(self, "git_sync_enabled")

    @git_sync_enabled.setter
    def git_sync_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "git_sync_enabled", value)

    @_builtins.property
    @pulumi.getter(name="isManualTriggerAuthorized")
    def is_manual_trigger_authorized(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When this is set to true, all manual triggers will require API Key authorization
        """
        return pulumi.get(self, "is_manual_trigger_authorized")

    @is_manual_trigger_authorized.setter
    def is_manual_trigger_authorized(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_manual_trigger_authorized", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the application
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("harness:index/application:Application")
class Application(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_manual_trigger_authorized: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for creating a Harness application

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        myapp = harness.Application("myapp",
            name="My Application",
            description="This is my first Harness application",
            tags=[
                "mytag:myvalue",
                "team:development",
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness application id

        ```sh
        $ pulumi import harness:index/application:Application myapp Xyz123
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The application description
        :param pulumi.Input[_builtins.bool] is_manual_trigger_authorized: When this is set to true, all manual triggers will require API Key authorization
        :param pulumi.Input[_builtins.str] name: The name of the application
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ApplicationArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness application

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        myapp = harness.Application("myapp",
            name="My Application",
            description="This is my first Harness application",
            tags=[
                "mytag:myvalue",
                "team:development",
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness application id

        ```sh
        $ pulumi import harness:index/application:Application myapp Xyz123
        ```

        :param str resource_name: The name of the resource.
        :param ApplicationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApplicationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_manual_trigger_authorized: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApplicationArgs.__new__(ApplicationArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["is_manual_trigger_authorized"] = is_manual_trigger_authorized
            __props__.__dict__["name"] = name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["git_sync_connector_id"] = None
            __props__.__dict__["git_sync_enabled"] = None
        super(Application, __self__).__init__(
            'harness:index/application:Application',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            git_sync_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
            git_sync_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            is_manual_trigger_authorized: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'Application':
        """
        Get an existing Application resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The application description
        :param pulumi.Input[_builtins.str] git_sync_connector_id: The id of the git sync connector
        :param pulumi.Input[_builtins.bool] git_sync_enabled: True if git sync is enabled on this application
        :param pulumi.Input[_builtins.bool] is_manual_trigger_authorized: When this is set to true, all manual triggers will require API Key authorization
        :param pulumi.Input[_builtins.str] name: The name of the application
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApplicationState.__new__(_ApplicationState)

        __props__.__dict__["description"] = description
        __props__.__dict__["git_sync_connector_id"] = git_sync_connector_id
        __props__.__dict__["git_sync_enabled"] = git_sync_enabled
        __props__.__dict__["is_manual_trigger_authorized"] = is_manual_trigger_authorized
        __props__.__dict__["name"] = name
        __props__.__dict__["tags"] = tags
        return Application(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The application description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="gitSyncConnectorId")
    def git_sync_connector_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the git sync connector
        """
        return pulumi.get(self, "git_sync_connector_id")

    @_builtins.property
    @pulumi.getter(name="gitSyncEnabled")
    def git_sync_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        True if git sync is enabled on this application
        """
        return pulumi.get(self, "git_sync_enabled")

    @_builtins.property
    @pulumi.getter(name="isManualTriggerAuthorized")
    def is_manual_trigger_authorized(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        When this is set to true, all manual triggers will require API Key authorization
        """
        return pulumi.get(self, "is_manual_trigger_authorized")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the application
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetGitopsRepoCertResult',
    'AwaitableGetGitopsRepoCertResult',
    'get_gitops_repo_cert',
    'get_gitops_repo_cert_output',
]

@pulumi.output_type
class GetGitopsRepoCertResult:
    """
    A collection of values returned by getGitopsRepoCert.
    """
    def __init__(__self__, account_id=None, agent_id=None, id=None, org_id=None, project_id=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if agent_id and not isinstance(agent_id, str):
            raise TypeError("Expected argument 'agent_id' to be a str")
        pulumi.set(__self__, "agent_id", agent_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> _builtins.str:
        """
        Account identifier of the GitOps repository certificate.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> _builtins.str:
        """
        Agent identifier of the GitOps repository certificate.
        """
        return pulumi.get(self, "agent_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Organization identifier of the GitOps repository certificate.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Project identifier of the GitOps repository certificate.
        """
        return pulumi.get(self, "project_id")


class AwaitableGetGitopsRepoCertResult(GetGitopsRepoCertResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGitopsRepoCertResult(
            account_id=self.account_id,
            agent_id=self.agent_id,
            id=self.id,
            org_id=self.org_id,
            project_id=self.project_id)


def get_gitops_repo_cert(account_id: Optional[_builtins.str] = None,
                         agent_id: Optional[_builtins.str] = None,
                         org_id: Optional[_builtins.str] = None,
                         project_id: Optional[_builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGitopsRepoCertResult:
    """
    Data source for retrieving a GitOps Repository Certificate. It fetches all the certificates that are added to the provided agent.

    ## Example Usage


    :param _builtins.str account_id: Account identifier of the GitOps repository certificate.
    :param _builtins.str agent_id: Agent identifier of the GitOps repository certificate.
    :param _builtins.str org_id: Organization identifier of the GitOps repository certificate.
    :param _builtins.str project_id: Project identifier of the GitOps repository certificate.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['agentId'] = agent_id
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getGitopsRepoCert:getGitopsRepoCert', __args__, opts=opts, typ=GetGitopsRepoCertResult).value

    return AwaitableGetGitopsRepoCertResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        agent_id=pulumi.get(__ret__, 'agent_id'),
        id=pulumi.get(__ret__, 'id'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'))
def get_gitops_repo_cert_output(account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                                org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGitopsRepoCertResult]:
    """
    Data source for retrieving a GitOps Repository Certificate. It fetches all the certificates that are added to the provided agent.

    ## Example Usage


    :param _builtins.str account_id: Account identifier of the GitOps repository certificate.
    :param _builtins.str agent_id: Agent identifier of the GitOps repository certificate.
    :param _builtins.str org_id: Organization identifier of the GitOps repository certificate.
    :param _builtins.str project_id: Project identifier of the GitOps repository certificate.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['agentId'] = agent_id
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getGitopsRepoCert:getGitopsRepoCert', __args__, opts=opts, typ=GetGitopsRepoCertResult)
    return __ret__.apply(lambda __response__: GetGitopsRepoCertResult(
        account_id=pulumi.get(__response__, 'account_id'),
        agent_id=pulumi.get(__response__, 'agent_id'),
        id=pulumi.get(__response__, 'id'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTerraformCloudConnectorResult',
    'AwaitableGetTerraformCloudConnectorResult',
    'get_terraform_cloud_connector',
    'get_terraform_cloud_connector_output',
]

@pulumi.output_type
class GetTerraformCloudConnectorResult:
    """
    A collection of values returned by getTerraformCloudConnector.
    """
    def __init__(__self__, credentials=None, delegate_selectors=None, description=None, id=None, identifier=None, name=None, org_id=None, project_id=None, tags=None, url=None):
        if credentials and not isinstance(credentials, list):
            raise TypeError("Expected argument 'credentials' to be a list")
        pulumi.set(__self__, "credentials", credentials)
        if delegate_selectors and not isinstance(delegate_selectors, list):
            raise TypeError("Expected argument 'delegate_selectors' to be a list")
        pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter
    def credentials(self) -> Sequence['outputs.GetTerraformCloudConnectorCredentialResult']:
        return pulumi.get(self, "credentials")

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Sequence[_builtins.str]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def url(self) -> _builtins.str:
        return pulumi.get(self, "url")


class AwaitableGetTerraformCloudConnectorResult(GetTerraformCloudConnectorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTerraformCloudConnectorResult(
            credentials=self.credentials,
            delegate_selectors=self.delegate_selectors,
            description=self.description,
            id=self.id,
            identifier=self.identifier,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            tags=self.tags,
            url=self.url)


def get_terraform_cloud_connector(identifier: Optional[_builtins.str] = None,
                                  name: Optional[_builtins.str] = None,
                                  org_id: Optional[_builtins.str] = None,
                                  project_id: Optional[_builtins.str] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTerraformCloudConnectorResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_terraform_cloud_connector(identifier="identifier")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getTerraformCloudConnector:getTerraformCloudConnector', __args__, opts=opts, typ=GetTerraformCloudConnectorResult).value

    return AwaitableGetTerraformCloudConnectorResult(
        credentials=pulumi.get(__ret__, 'credentials'),
        delegate_selectors=pulumi.get(__ret__, 'delegate_selectors'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'),
        url=pulumi.get(__ret__, 'url'))
def get_terraform_cloud_connector_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                         name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                         org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                         project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTerraformCloudConnectorResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_terraform_cloud_connector(identifier="identifier")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getTerraformCloudConnector:getTerraformCloudConnector', __args__, opts=opts, typ=GetTerraformCloudConnectorResult)
    return __ret__.apply(lambda __response__: GetTerraformCloudConnectorResult(
        credentials=pulumi.get(__response__, 'credentials'),
        delegate_selectors=pulumi.get(__response__, 'delegate_selectors'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags'),
        url=pulumi.get(__response__, 'url')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TasConnectorArgs', 'TasConnector']

@pulumi.input_type
class TasConnectorArgs:
    def __init__(__self__, *,
                 credentials: pulumi.Input['TasConnectorCredentialsArgs'],
                 identifier: pulumi.Input[_builtins.str],
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 execute_on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a TasConnector resource.
        :param pulumi.Input['TasConnectorCredentialsArgs'] credentials: Contains Tas connector credentials.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] execute_on_delegate: Execute on delegate or not.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        pulumi.set(__self__, "credentials", credentials)
        pulumi.set(__self__, "identifier", identifier)
        if delegate_selectors is not None:
            pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if execute_on_delegate is not None:
            pulumi.set(__self__, "execute_on_delegate", execute_on_delegate)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def credentials(self) -> pulumi.Input['TasConnectorCredentialsArgs']:
        """
        Contains Tas connector credentials.
        """
        return pulumi.get(self, "credentials")

    @credentials.setter
    def credentials(self, value: pulumi.Input['TasConnectorCredentialsArgs']):
        pulumi.set(self, "credentials", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @delegate_selectors.setter
    def delegate_selectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "delegate_selectors", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="executeOnDelegate")
    def execute_on_delegate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Execute on delegate or not.
        """
        return pulumi.get(self, "execute_on_delegate")

    @execute_on_delegate.setter
    def execute_on_delegate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "execute_on_delegate", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _TasConnectorState:
    def __init__(__self__, *,
                 credentials: Optional[pulumi.Input['TasConnectorCredentialsArgs']] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 execute_on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering TasConnector resources.
        :param pulumi.Input['TasConnectorCredentialsArgs'] credentials: Contains Tas connector credentials.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] execute_on_delegate: Execute on delegate or not.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        if credentials is not None:
            pulumi.set(__self__, "credentials", credentials)
        if delegate_selectors is not None:
            pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if execute_on_delegate is not None:
            pulumi.set(__self__, "execute_on_delegate", execute_on_delegate)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def credentials(self) -> Optional[pulumi.Input['TasConnectorCredentialsArgs']]:
        """
        Contains Tas connector credentials.
        """
        return pulumi.get(self, "credentials")

    @credentials.setter
    def credentials(self, value: Optional[pulumi.Input['TasConnectorCredentialsArgs']]):
        pulumi.set(self, "credentials", value)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @delegate_selectors.setter
    def delegate_selectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "delegate_selectors", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="executeOnDelegate")
    def execute_on_delegate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Execute on delegate or not.
        """
        return pulumi.get(self, "execute_on_delegate")

    @execute_on_delegate.setter
    def execute_on_delegate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "execute_on_delegate", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("harness:platform/tasConnector:TasConnector")
class TasConnector(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 credentials: Optional[pulumi.Input[Union['TasConnectorCredentialsArgs', 'TasConnectorCredentialsArgsDict']]] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 execute_on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for creating an Tas in Harness.

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level tas connector

        ```sh
        $ pulumi import harness:platform/tasConnector:TasConnector example <connector_id>
        ```

        Import organization level tas connector

        ```sh
        $ pulumi import harness:platform/tasConnector:TasConnector example <organization_id>/<connector_id>
        ```

        Import project level tas connector

        ```sh
        $ pulumi import harness:platform/tasConnector:TasConnector example <organization_id>/<project_id>/<connector_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['TasConnectorCredentialsArgs', 'TasConnectorCredentialsArgsDict']] credentials: Contains Tas connector credentials.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] execute_on_delegate: Execute on delegate or not.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TasConnectorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating an Tas in Harness.

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level tas connector

        ```sh
        $ pulumi import harness:platform/tasConnector:TasConnector example <connector_id>
        ```

        Import organization level tas connector

        ```sh
        $ pulumi import harness:platform/tasConnector:TasConnector example <organization_id>/<connector_id>
        ```

        Import project level tas connector

        ```sh
        $ pulumi import harness:platform/tasConnector:TasConnector example <organization_id>/<project_id>/<connector_id>
        ```

        :param str resource_name: The name of the resource.
        :param TasConnectorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TasConnectorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 credentials: Optional[pulumi.Input[Union['TasConnectorCredentialsArgs', 'TasConnectorCredentialsArgsDict']]] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 execute_on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TasConnectorArgs.__new__(TasConnectorArgs)

            if credentials is None and not opts.urn:
                raise TypeError("Missing required property 'credentials'")
            __props__.__dict__["credentials"] = credentials
            __props__.__dict__["delegate_selectors"] = delegate_selectors
            __props__.__dict__["description"] = description
            __props__.__dict__["execute_on_delegate"] = execute_on_delegate
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
        super(TasConnector, __self__).__init__(
            'harness:platform/tasConnector:TasConnector',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            credentials: Optional[pulumi.Input[Union['TasConnectorCredentialsArgs', 'TasConnectorCredentialsArgsDict']]] = None,
            delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            execute_on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'TasConnector':
        """
        Get an existing TasConnector resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['TasConnectorCredentialsArgs', 'TasConnectorCredentialsArgsDict']] credentials: Contains Tas connector credentials.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] execute_on_delegate: Execute on delegate or not.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TasConnectorState.__new__(_TasConnectorState)

        __props__.__dict__["credentials"] = credentials
        __props__.__dict__["delegate_selectors"] = delegate_selectors
        __props__.__dict__["description"] = description
        __props__.__dict__["execute_on_delegate"] = execute_on_delegate
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        return TasConnector(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def credentials(self) -> pulumi.Output['outputs.TasConnectorCredentials']:
        """
        Contains Tas connector credentials.
        """
        return pulumi.get(self, "credentials")

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="executeOnDelegate")
    def execute_on_delegate(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Execute on delegate or not.
        """
        return pulumi.get(self, "execute_on_delegate")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDefaultNotificationTemplateSetResult',
    'AwaitableGetDefaultNotificationTemplateSetResult',
    'get_default_notification_template_set',
    'get_default_notification_template_set_output',
]

@pulumi.output_type
class GetDefaultNotificationTemplateSetResult:
    """
    A collection of values returned by getDefaultNotificationTemplateSet.
    """
    def __init__(__self__, created=None, description=None, event_template_configuration_sets=None, id=None, identifier=None, last_modified=None, name=None, notification_channel_type=None, notification_entity=None, org=None, org_id=None, project=None, project_id=None, tags=None):
        if created and not isinstance(created, int):
            raise TypeError("Expected argument 'created' to be a int")
        pulumi.set(__self__, "created", created)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if event_template_configuration_sets and not isinstance(event_template_configuration_sets, list):
            raise TypeError("Expected argument 'event_template_configuration_sets' to be a list")
        pulumi.set(__self__, "event_template_configuration_sets", event_template_configuration_sets)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if last_modified and not isinstance(last_modified, int):
            raise TypeError("Expected argument 'last_modified' to be a int")
        pulumi.set(__self__, "last_modified", last_modified)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if notification_channel_type and not isinstance(notification_channel_type, str):
            raise TypeError("Expected argument 'notification_channel_type' to be a str")
        pulumi.set(__self__, "notification_channel_type", notification_channel_type)
        if notification_entity and not isinstance(notification_entity, str):
            raise TypeError("Expected argument 'notification_entity' to be a str")
        pulumi.set(__self__, "notification_entity", notification_entity)
        if org and not isinstance(org, str):
            raise TypeError("Expected argument 'org' to be a str")
        pulumi.set(__self__, "org", org)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.int:
        """
        Timestamp when the notification rule was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        Description for Default Notification Template Set
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="eventTemplateConfigurationSets")
    def event_template_configuration_sets(self) -> Sequence['outputs.GetDefaultNotificationTemplateSetEventTemplateConfigurationSetResult']:
        """
        Set of event-template configurations
        """
        return pulumi.get(self, "event_template_configuration_sets")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of Default Notification Template Set
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="lastModified")
    def last_modified(self) -> _builtins.int:
        """
        Timestamp when the notification rule was last modified.
        """
        return pulumi.get(self, "last_modified")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of Default Notification Template Set
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notificationChannelType")
    def notification_channel_type(self) -> _builtins.str:
        """
        Type of channel (e.g. SLACK, EMAIL, etc.)
        """
        return pulumi.get(self, "notification_channel_type")

    @_builtins.property
    @pulumi.getter(name="notificationEntity")
    def notification_entity(self) -> _builtins.str:
        """
        Type of the entity (e.g. PIPELINE, SERVICE, etc.)
        """
        return pulumi.get(self, "notification_entity")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release. Please use 'org_id' instead.""")
    def org(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization. Use `org_id` instead.
        """
        return pulumi.get(self, "org")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release. Please use 'project_id' instead.""")
    def project(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project. Use `project_id` instead.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, _builtins.str]]:
        """
        Key-value tags
        """
        return pulumi.get(self, "tags")


class AwaitableGetDefaultNotificationTemplateSetResult(GetDefaultNotificationTemplateSetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDefaultNotificationTemplateSetResult(
            created=self.created,
            description=self.description,
            event_template_configuration_sets=self.event_template_configuration_sets,
            id=self.id,
            identifier=self.identifier,
            last_modified=self.last_modified,
            name=self.name,
            notification_channel_type=self.notification_channel_type,
            notification_entity=self.notification_entity,
            org=self.org,
            org_id=self.org_id,
            project=self.project,
            project_id=self.project_id,
            tags=self.tags)


def get_default_notification_template_set(description: Optional[_builtins.str] = None,
                                          event_template_configuration_sets: Optional[Sequence[Union['GetDefaultNotificationTemplateSetEventTemplateConfigurationSetArgs', 'GetDefaultNotificationTemplateSetEventTemplateConfigurationSetArgsDict']]] = None,
                                          identifier: Optional[_builtins.str] = None,
                                          name: Optional[_builtins.str] = None,
                                          notification_channel_type: Optional[_builtins.str] = None,
                                          notification_entity: Optional[_builtins.str] = None,
                                          org: Optional[_builtins.str] = None,
                                          org_id: Optional[_builtins.str] = None,
                                          project: Optional[_builtins.str] = None,
                                          project_id: Optional[_builtins.str] = None,
                                          tags: Optional[Mapping[str, _builtins.str]] = None,
                                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDefaultNotificationTemplateSetResult:
    """
    Data source for retrieving a Default Notification Template Set.


    :param _builtins.str description: Description for Default Notification Template Set
    :param Sequence[Union['GetDefaultNotificationTemplateSetEventTemplateConfigurationSetArgs', 'GetDefaultNotificationTemplateSetEventTemplateConfigurationSetArgsDict']] event_template_configuration_sets: Set of event-template configurations
    :param _builtins.str identifier: Identifier of Default Notification Template Set
    :param _builtins.str name: Name of Default Notification Template Set
    :param _builtins.str notification_channel_type: Type of channel (e.g. SLACK, EMAIL, etc.)
    :param _builtins.str notification_entity: Type of the entity (e.g. PIPELINE, SERVICE, etc.)
    :param _builtins.str org: Unique identifier of the organization. Use `org_id` instead.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project: Unique identifier of the project. Use `project_id` instead.
    :param _builtins.str project_id: Unique identifier of the project.
    :param Mapping[str, _builtins.str] tags: Key-value tags
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['eventTemplateConfigurationSets'] = event_template_configuration_sets
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['notificationChannelType'] = notification_channel_type
    __args__['notificationEntity'] = notification_entity
    __args__['org'] = org
    __args__['orgId'] = org_id
    __args__['project'] = project
    __args__['projectId'] = project_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getDefaultNotificationTemplateSet:getDefaultNotificationTemplateSet', __args__, opts=opts, typ=GetDefaultNotificationTemplateSetResult).value

    return AwaitableGetDefaultNotificationTemplateSetResult(
        created=pulumi.get(__ret__, 'created'),
        description=pulumi.get(__ret__, 'description'),
        event_template_configuration_sets=pulumi.get(__ret__, 'event_template_configuration_sets'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        last_modified=pulumi.get(__ret__, 'last_modified'),
        name=pulumi.get(__ret__, 'name'),
        notification_channel_type=pulumi.get(__ret__, 'notification_channel_type'),
        notification_entity=pulumi.get(__ret__, 'notification_entity'),
        org=pulumi.get(__ret__, 'org'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project=pulumi.get(__ret__, 'project'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_default_notification_template_set_output(description: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                                 event_template_configuration_sets: Optional[pulumi.Input[Sequence[Union['GetDefaultNotificationTemplateSetEventTemplateConfigurationSetArgs', 'GetDefaultNotificationTemplateSetEventTemplateConfigurationSetArgsDict']]]] = None,
                                                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                                 name: Optional[pulumi.Input[_builtins.str]] = None,
                                                 notification_channel_type: Optional[pulumi.Input[_builtins.str]] = None,
                                                 notification_entity: Optional[pulumi.Input[_builtins.str]] = None,
                                                 org: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                                 org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                                 project: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                                 project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                                 tags: Optional[pulumi.Input[Optional[Mapping[str, _builtins.str]]]] = None,
                                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDefaultNotificationTemplateSetResult]:
    """
    Data source for retrieving a Default Notification Template Set.


    :param _builtins.str description: Description for Default Notification Template Set
    :param Sequence[Union['GetDefaultNotificationTemplateSetEventTemplateConfigurationSetArgs', 'GetDefaultNotificationTemplateSetEventTemplateConfigurationSetArgsDict']] event_template_configuration_sets: Set of event-template configurations
    :param _builtins.str identifier: Identifier of Default Notification Template Set
    :param _builtins.str name: Name of Default Notification Template Set
    :param _builtins.str notification_channel_type: Type of channel (e.g. SLACK, EMAIL, etc.)
    :param _builtins.str notification_entity: Type of the entity (e.g. PIPELINE, SERVICE, etc.)
    :param _builtins.str org: Unique identifier of the organization. Use `org_id` instead.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project: Unique identifier of the project. Use `project_id` instead.
    :param _builtins.str project_id: Unique identifier of the project.
    :param Mapping[str, _builtins.str] tags: Key-value tags
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['eventTemplateConfigurationSets'] = event_template_configuration_sets
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['notificationChannelType'] = notification_channel_type
    __args__['notificationEntity'] = notification_entity
    __args__['org'] = org
    __args__['orgId'] = org_id
    __args__['project'] = project
    __args__['projectId'] = project_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getDefaultNotificationTemplateSet:getDefaultNotificationTemplateSet', __args__, opts=opts, typ=GetDefaultNotificationTemplateSetResult)
    return __ret__.apply(lambda __response__: GetDefaultNotificationTemplateSetResult(
        created=pulumi.get(__response__, 'created'),
        description=pulumi.get(__response__, 'description'),
        event_template_configuration_sets=pulumi.get(__response__, 'event_template_configuration_sets'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        last_modified=pulumi.get(__response__, 'last_modified'),
        name=pulumi.get(__response__, 'name'),
        notification_channel_type=pulumi.get(__response__, 'notification_channel_type'),
        notification_entity=pulumi.get(__response__, 'notification_entity'),
        org=pulumi.get(__response__, 'org'),
        org_id=pulumi.get(__response__, 'org_id'),
        project=pulumi.get(__response__, 'project'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetCurrentAccountResult',
    'AwaitableGetCurrentAccountResult',
    'get_current_account',
    'get_current_account_output',
]

@pulumi.output_type
class GetCurrentAccountResult:
    """
    A collection of values returned by getCurrentAccount.
    """
    def __init__(__self__, account_id=None, endpoint=None, id=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if endpoint and not isinstance(endpoint, str):
            raise TypeError("Expected argument 'endpoint' to be a str")
        pulumi.set(__self__, "endpoint", endpoint)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> _builtins.str:
        """
        Id of the account.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> _builtins.str:
        """
        The url of the Harness control plane.
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        Id of the account.
        """
        return pulumi.get(self, "id")


class AwaitableGetCurrentAccountResult(GetCurrentAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCurrentAccountResult(
            account_id=self.account_id,
            endpoint=self.endpoint,
            id=self.id)


def get_current_account(id: Optional[_builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCurrentAccountResult:
    """
    Data source for retrieving information about the current Harness account


    :param _builtins.str id: Id of the account.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getCurrentAccount:getCurrentAccount', __args__, opts=opts, typ=GetCurrentAccountResult).value

    return AwaitableGetCurrentAccountResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        endpoint=pulumi.get(__ret__, 'endpoint'),
        id=pulumi.get(__ret__, 'id'))
def get_current_account_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCurrentAccountResult]:
    """
    Data source for retrieving information about the current Harness account


    :param _builtins.str id: Id of the account.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getCurrentAccount:getCurrentAccount', __args__, opts=opts, typ=GetCurrentAccountResult)
    return __ret__.apply(lambda __response__: GetCurrentAccountResult(
        account_id=pulumi.get(__response__, 'account_id'),
        endpoint=pulumi.get(__response__, 'endpoint'),
        id=pulumi.get(__response__, 'id')))
